==> haskell-lsp-test-0.15.0.1-66.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.15.0.1
visibility:           public
id:                   lsp-test-0.15.0.1-KuiVyYsgFJwBYTaqsBcaZ8
key:                  lsp-test-0.15.0.1-KuiVyYsgFJwBYTaqsBcaZ8
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  df77b55a221e0a55b2516ee569b1f5f5
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48:Control.Applicative.Combinators,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Message from lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK:Language.LSP.Protocol.Types,
    Language.LSP.Test

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-test-0.15.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-test-0.15.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-test-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.15.0.1-KuiVyYsgFJwBYTaqsBcaZ8
depends:
    Diff-0.5-yETzKh0qtuDUuvJdOns8X Glob-0.10.2-AkNemguOk3X5pWzckA4YZJ
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    aeson-pretty-0.8.10-CQgtmRgYKKmDAUdx88Og8E
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-F1cXOLptdAs7fL36TTB1WQ
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-parse-0.2.1.1-KY2VXVsm7Pf4EdUEsh1TCl containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48 process-1.6.19.0
    row-types-1.0.1.2-FuMsfCVBkwF72uFC405BUE
    some-1.0.6-1FUKmKhhCiB9O9TtG7osbe text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test-0.15.0.1-67-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.15.0.1
visibility:           public
id:                   lsp-test-0.15.0.1-G1KOIGMqj5U8dP5sBy33Es
key:                  lsp-test-0.15.0.1-G1KOIGMqj5U8dP5sBy33Es
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  eebce8e5c54878bc41fe2e91f57ab11d
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48:Control.Applicative.Combinators,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Message from lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3:Language.LSP.Protocol.Types,
    Language.LSP.Test

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-test-0.15.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-test-0.15.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-test-0.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test
hs-libraries:         HSlsp-test-0.15.0.1-G1KOIGMqj5U8dP5sBy33Es
depends:
    Diff-0.5-8gj4s2z6jOl7FPRCGftIez Glob-0.10.2-5kv8V0ytwO85Bs2S1wsFnS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    aeson-pretty-0.8.10-BjxB783FV8e8YPhrNbMs4J
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-3ZAPJG8B8UQLXQ3UK4qwOj
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-parse-0.2.1.1-K22E6x2csHtJqEAHopmFKW containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3 mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48 process-1.6.19.0
    row-types-1.0.1.2-Lk5eej2rV6aHvk9G3xl6hA
    some-1.0.6-1FUKmKhhCiB9O9TtG7osbe text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
